@@ -9,6 +9,7 @@ class MultiView : public Lum::Group
 {
 private:
   std::list<Base::ViewPtr> views;
+  Base::ViewPtr            hidden;
   Base::ViewPtr            current;
 
 public:
@@ -19,6 +20,7 @@ public:
 
   void CalcSize();
   void Layout();
+  void Draw(Lum::OS::DrawInfo* draw, int x, int y, size_t w, size_t h);
 
   void AddView(Base::ViewPtr view);
   void ShowView(const std::wstring& name, Base::View::DataPtr data);
